@@ -45,11 +45,12 @@ class Device:
         self.device = None
         self.plcnet = None
 
+        self._connected = False
         self._info: Dict = {
             "_dvl-plcnetapi._tcp.local.": plcnetapi or EMPTY_INFO,
             "_dvl-deviceapi._tcp.local.": deviceapi or EMPTY_INFO,
         }
-        self._logger = logging.getLogger(self.__class__.__name__)
+        self._logger = logging.getLogger(f"{self.__class__.__module__}.{self.__class__.__name__}")
         self._password = ""
         self._session_instance: Optional[httpx.AsyncClient] = None
         self._zeroconf_instance = zeroconf_instance
@@ -60,7 +61,7 @@ class Device:
         self._zeroconf: Zeroconf
 
     def __del__(self):
-        if self._loop.is_running():
+        if self._connected and self._session_instance is None:
             self._logger.warning("Please disconnect properly from the device.")
 
     async def __aenter__(self):
@@ -102,6 +103,7 @@ class Device:
         await asyncio.gather(self._get_device_info(), self._get_plcnet_info())
         if not self.device and not self.plcnet:
             raise DeviceNotFound(f"The device {self.ip} did not answer.")
+        self._connected = True
 
     def connect(self):
         """ Connect to a device synchronous. """
@@ -114,6 +116,7 @@ class Device:
             self._zeroconf.close()
         if not self._session_instance:
             await self._session.aclose()
+        self._connected = False
 
     def disconnect(self):
         """ Disconnect from a device asynchronous. """
